On 14/02/2016 19:42, Varun Prakash wrote:
ISCSI_TCP_CXGB4 driver waits on conn_logout_comp as
ISCSI_TCP driver so call complete if transport type
is ISCSI_TCP_CXGB4.

Signed-off-by: Varun Prakash <va...@chelsio.com>
---
  drivers/target/iscsi/iscsi_target.c | 10 ++++++----
  1 file changed, 6 insertions(+), 4 deletions(-)

diff --git a/drivers/target/iscsi/iscsi_target.c 
b/drivers/target/iscsi/iscsi_target.c
index 8bf3cfb..858f6e4 100644
--- a/drivers/target/iscsi/iscsi_target.c
+++ b/drivers/target/iscsi/iscsi_target.c
@@ -4265,16 +4265,18 @@ int iscsit_close_connection(
        pr_debug("Closing iSCSI connection CID %hu on SID:"
                " %u\n", conn->cid, sess->sid);
        /*
         * Always up conn_logout_comp for the traditional TCP case just in case
         * the RX Thread in iscsi_target_rx_opcode() is sleeping and the logout
         * response never got sent because the connection failed.
         *
         * However for iser-target, isert_wait4logout() is using 
conn_logout_comp
         * to signal logout response TX interrupt completion.  Go ahead and skip
         * this for iser since isert_rx_opcode() does not wait on logout 
failure,
         * and to avoid iscsi_conn pointer dereference in iser-target code.
         */
-       if (conn->conn_transport->transport_type == ISCSI_TCP)
+       if ((conn->conn_transport->transport_type == ISCSI_TCP) ||
+           (conn->conn_transport->transport_type == ISCSI_TCP_CXGB4))
                complete(&conn->conn_logout_comp);
@@ -4265,16 +4265,18 @@ int iscsit_close_connection(
                " %u\n", conn->cid, sess->sid);
        /*
-        * Always up conn_logout_comp for the traditional TCP case just in case
-        * the RX Thread in iscsi_target_rx_opcode() is sleeping and the logout
-        * response never got sent because the connection failed.
+        * Always up conn_logout_comp for the traditional TCP and TCP_CXGB4
+        * case just in case the RX Thread in iscsi_target_rx_opcode() is
+        * sleeping and the logout response never got sent because the
+        * connection failed.
         *
         * However for iser-target, isert_wait4logout() is using 

IMO, this is an indication that this condition is a bandage in the first
place...

While this is unrelated to the patch set, we should look into the iscsi
termination sequences more closely and look if we can dispatch some
logic to the drivers in places they defer. It will make the code much
less complicated.
--
To unsubscribe from this list: send the line "unsubscribe linux-scsi" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to